#!/usr/bin/bash
#
# This binary is made to be run by git server, it builds a rpm package and send a request to root in order
# to deploy the package on the server.

# Exit immediately if any command fails.
set -e

# Exit with the last non-zero exit code.
set -o pipefail

# Name of current gitops pipeline.
pipeline="NEWTAG"

log () {
	echo -e "[$pipeline] $(date --rfc-3339=s) - $1"
}

fail () {
	if [ $# -eq 1 ]; then
		echo "$1" 1>&2
	fi
	exit 1
}

# Retrieve necessary details about package.
pkg_name=$(make name)
[ -z $pkg_name ] && fail "Empty result for target 'make name'."
pkg_version=$(make version)
[ -z $pkg_version ] && fail "Empty result for target 'make version'."

# Check code validity.
log "Check code validity for $pkg_name v$pkg_version."
make check_format
make check_linting
make unit_test

# Make tarball with source code.
log "Make source tarball for $pkg_name v$pkg_version."
make tarball

# Build rpm package.
log "Build rpm package."
rpmbuild -bb "$pkg_name.spec"

# Cleanup last response.
[ -f "$NETOIK_CICD_DEPLOYER_RESPONSE_DIR/$pkg_name" ] || touch "$NETOIK_CICD_DEPLOYER_RESPONSE_DIR/$pkg_name"
sed -i "d" "$NETOIK_CICD_DEPLOYER_RESPONSE_DIR/$pkg_name"

# Send request to deployer with a little delay in background.
log "Install or update rpm package."
echo "$pkg_version" > "$NETOIK_CICD_DEPLOYER_REQUEST_DIR/$pkg_name"

# Wait for response from deployer.
inotifywait --timeout 600 --event modify "$NETOIK_CICD_DEPLOYER_RESPONSE_DIR/$pkg_name" >/dev/null

# Get content of the response.
while read line; do
	[ -z "$previous" ] || echo "$previous"
	previous="$line"
done < "$NETOIK_CICD_DEPLOYER_RESPONSE_DIR/$pkg_name"

# Exit now with exit code found in response.
exit_code=$(printf "%d\n" "$previous")
exit $exit_code 
